Learn R Programming

mnt (version 1.4)

DEHT: Statistic of the DEH test based on harmonic oscillator

Description

Computes the test statistic of the DEH test.

Usage

DEHT(data, a = 1)

Value

The value of the test statistic.

Arguments

data

a n x d numeric matrix of data values.

a

positive numeric number (tuning parameter).

Details

This functions evaluates the teststatistic with the given data and the specified tuning parameter a. Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly \(n \ge d+1\) is needed. If that is not the case the test returns an error.

References

Dörr, P., Ebner, B., Henze, N. (2020) "Testing multivariate normality by zeros of the harmonic oscillator in characteristic function spaces", Scandinavian Journal of Statistics, 48(2): 456-501, tools:::Rd_expr_doi("10.1111/sjos.12477").

Examples

Run this code
DEHT(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=1)

Run the code above in your browser using DataLab