View source: R/teststatistics.R
| DEHU | R Documentation |
Computes the test statistic of the DEH based on a double estimation in PDE test.
DEHU(data, a)
data |
a (d,n) numeric matrix containing the data. |
a |
positive numeric number (tuning parameter). |
This functions evaluates the teststatistic with the given data and the specified tuning parameter a.
Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly
n \ge d+1 is needed. If that is not the case the test returns an error.
The value of the test statistic.
Dörr, P., Ebner, B., Henze, N. (2021) "A new test of multivariate normality by a double estimation in a characterizing PDE" Metrika 84: 401-427, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s00184-020-00795-x")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.