View source: R/teststatistics.R
| EHS | R Documentation |
Computes the test statistic of the EHS test based on a multivariate Stein equation.
EHS(data, a = 1)
data |
a (d,n) numeric matrix containing the data. |
a |
positive numeric number (tuning parameter). |
This functions evaluates the teststatistic with the given data and the specified tuning parameter a.
Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly
n \ge d+1 is needed. If that is not the case the test returns an error.
Note that a=Inf returns the limiting test statistic with value 2*MSkew + MRSSkew and a=0 returns the value of the limit statistic
T_{n,0}=\frac{d}{2}-2^{\frac{d}{2}+1}\frac{1}{n}\sum_{j=1}^n\|Y_{n,j}\|^2\exp(-\frac{\|Y_{n,j}\|^2}{2}).
The value of the test statistic.
Ebner, B., Henze, N., Strieder, D. (2022) "Testing normality in any dimension by Fourier methods in a multivariate Stein equation", The Canadian Journal of Statistics, 50(3): 992-1033, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/cjs.11670")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.