View source: R/teststatistics.R
| HJG | R Documentation |
Computes the test statistic of the Henze-Jimenes-Gamero test.
HJG(data, a = 5)
data |
a n x d numeric matrix of data values. |
a |
positive numeric number (tuning parameter). |
This functions evaluates the teststatistic with the given data and the specified tuning parameter a.
Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly
n \ge d+1 is needed. If that is not the case the function returns an error.
The value of the test statistic.
Henze, N., Jiménez-Gamero, M.D. (2019) "A new class of tests for multinormality with i.i.d. and garch data based on the empirical moment generating function", TEST, 28, 499-521, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11749-018-0589-z")}
HJG(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.