View source: R/teststatistics.R
| HJM | R Documentation |
Computes the test statistic of the Henze-Jiménes-Gamero-Meintanis test.
HJM(data, a)
data |
a n x d numeric matrix of data values. |
a |
positive numeric number (tuning parameter). |
This functions evaluates the teststatistic with the given data and the specified tuning parameter a.
Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly
n \ge d+1 is needed. If that is not the case the function returns an error.
The value of the test statistic.
Henze, N., Jiménes-Gamero, M.D., Meintanis, S.G. (2019), Characterizations of multinormality and corresponding tests of fit, including for GARCH models, Econometric Th., 35:510–546, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/S0266466618000154")}.
HJM(MASS::mvrnorm(20,c(0,1),diag(1,2)),a=2.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.