Learn R Programming

mnt (version 1.4)

HZ: Statistic of the Henze-Zirkler test

Description

This function returns the value of the statistic of the BHEP test as in Henze and Zirkler (1990). The difference to the BHEP test is in the choice of the tuning parameter \(\beta\).

Usage

HZ(data)

Value

value of the test statistic.

Arguments

data

a n x d matrix of d dimensional data vectors.

Details

A BHEP test is performed with tuning parameter \(\beta\) chosen in dependence of the sample size n and the dimension d, namely $$\beta=\frac{((2d+1)n/4)^(1/(d+4))}{\sqrt{2}}.$$

References

Henze, N., and Zirkler, B. (1990), A class of invariant consistent tests for multivariate normality, Commun.-Statist. – Th. Meth., 19:3595–3617, tools:::Rd_expr_doi("10.1080/03610929008830400")

See Also

BHEP

Examples

Run this code
HZ(MASS::mvrnorm(50,c(0,1),diag(1,2)))

Run the code above in your browser using DataLab