View source: R/teststatistics.R
| MQ2 | R Documentation |
This function returns the value of the second statistic of Manzotti und Quiroz (2001).
MQ2(data)
data |
a n x d matrix of d dimensional data vectors. |
Value of the test statistic
Manzotti, A., and Quiroz, A.J. (2001), Spherical harmonics in quadratic forms for testing multivariate normality, Test, 10:87–104, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/BF02595825")}
MQ2(MASS::mvrnorm(50,c(0,1),diag(1,2)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.