Learn R Programming

mnt (version 1.4)

MRSSkew: multivariate skewness of Móri, Rohatgi and Székely

Description

This function computes the invariant measure of multivariate sample skewness due to Móri, Rohatgi and Székely (1993).

Usage

MRSSkew(data)

Value

value of sample skewness in the sense of Móri, Rohatgi and Székely.

Arguments

data

a n x d matrix of d dimensional data vectors.

Details

Multivariate sample skewness due to Móri, Rohatgi and Székely (1993) is defined by $$\widetilde{b}_{n,d}^{(1)}=\frac{1}{n}\sum_{j=1}^n\|Y_{n,j}\|^2\|Y_{n,k}\|^2Y_{n,j}^\top Y_{n,k},$$ where \(Y_{n,j}=S_n^{-1/2}(X_j-\overline{X}_n)\), \(\overline{X}_n\) is the sample mean and \(S_n\) is the sample covariance matrix of the random vectors \(X_1,\ldots,X_n\). To ensure that the computation works properly \(n \ge d+1\) is needed. If that is not the case the function returns an error. Note that for \(d=1\), it is equivalent to skewness in the sense of Mardia.

References

Móri, T. F., Rohatgi, V. K., Székely, G. J. (1993), On multivariate skewness and kurtosis, Theory of Probability and its Applications, 38:547–551.

Henze, N. (2002), Invariant tests for multivariate normality: a critical review, Statistical Papers, 43:467–506.