Description Usage Arguments Value References See Also Examples
View source: R/teststatistics.R
This function returns the value of the statistic of the test of multivariate normality (also called energy test) as in Székely and Rizzo (2005). Note that the scaled residuals use another scaling in the estimator of the covariance matrix as the other functions of the package mnt!
It is equivalent to the function mvnorm.e.
1 |
data |
a n x d matrix of d dimensional data vectors. |
abb |
Stop criterium. |
value of the test statistic.
Székely, G., and Rizzo, M. (2005), A new test for multivariate normality, J. Multiv. Anal., 93:58–80, DOI
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.