| mnt-package | R Documentation |
Various affine invariant multivariate normality tests are provided. It is designed to accompany the survey article Ebner, B. and Henze, N. (2020) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11749-020-00740-0")} titled "Tests for multivariate normality – a critical review with emphasis on weighted L^2-statistics". We implement new and time honoured L^2-type tests of multivariate normality, such as the Baringhaus-Henze-Epps-Pulley (BHEP) test, the Henze-Zirkler test, the test of Henze-Jiménes-Gamero, the test of Henze-Jiménes-Gamero-Meintanis, the test of Henze-Visage, the Dörr-Ebner-Henze test based on harmonic oscillator and the Dörr-Ebner-Henze test based on a double estimation in a PDE. Secondly, we include the measures of multivariate skewness and kurtosis by Mardia, Koziol, Malkovich and Afifi and Móri, Rohatgi and Székely, as well as the associated tests. Thirdly, we include the tests of multivariate normality by Cox and Small, the 'energy' test of Székely and Rizzo, the tests based on spherical harmonics by Manzotti and Quiroz and the test of Pudelko. All the functions and tests need the data to be a n x d matrix where n is the samplesize (number of rows) and d is the dimension (number of columns).
The tests implemented in mnt are calibrated for independent
and identically distributed observations. Applying them to residuals
from fitted models requires additional justification, because parameter
estimation may change the null distribution and invalidate the usual
critical values. As discussed by Jimenez-Gamero (2020) and acknowledged
by Ebner and Henze (2020), validity depends on both the test and the
underlying model.
Maintainer: Bruno Ebner bruno.ebner@kit.edu
Authors:
Bruno Ebner bruno.ebner@kit.edu
Lucas Butsch lucas.butsch@gmail.com
Other contributors:
Jaco Visagie jaco.visagie@nwu.ac.za [contributor]
Johann Siemens johann-siemens@web.de [contributor]
Jimenez-Gamero, M. D. (2020). Comments on: Tests for multivariate normality—a critical review with emphasis on weighted L2-statistics. TEST, 29, 893–897. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11749-020-00742-y")}.
Ebner, B. and Henze, N. (2020). Rejoinder on: Tests for multivariate normality—a critical review with emphasis on weighted L2-statistics. TEST, 29, 911–913. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11749-020-00744-w")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.