| print.mnt | R Documentation |
Printing objects of class "mnt".
## S3 method for class 'mnt'
print(x, ...)
x |
object of class "mnt". |
... |
further arguments to be passed to or from methods. |
A mnt object is a named list of numbers and character string, supplemented with test (the name of the teststatistic). test is displayed as a title.
The remaining elements are given in an aligned "name = value" format.
the argument x, invisibly, as for all print methods.
print(test.DEHU(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=1,MC=500))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.