standard: Empirical scaled residuals

View source: R/helpFunctions.R

standardR Documentation

Empirical scaled residuals

Description

A function that computes the scaled residuals of the data.

Usage

standard(data)

Arguments

data

a n x d matrix of d dimensional data vectors..

Value

A n x d matrix of the scaled residuals.


mnt documentation built on Sept. 25, 2026, 5:08 p.m.