| test.HJG | R Documentation |
Computes the multivariate normality test of Henze and Jimenes-Gamero (2019) in dependence of a tuning parameter a.
test.HJG(data, a = 1, MC.rep = 10000, alpha = 0.05)
data |
a n x d matrix of d dimensional data vectors. |
a |
positive numeric number (tuning parameter). |
MC.rep |
number of repetitions for the Monte Carlo simulation of the critical value. |
alpha |
level of significance of the test. |
This functions evaluates the teststatistic with the given data and the specified tuning parameter a.
Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly
n \ge d+1 is needed. If that is not the case the test returns an error.
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Testname of the test.
$paramvalue tuning parameter.
$Test.valuethe value of the test statistic.
$cvthe approximated critical value.
$Decisionthe comparison of the critical value and the value of the test statistic.
#'
Henze, N., Jimenez-Gamero, M.D. (2019) "A new class of tests for multinormality with i.i.d. and garch data based on the empirical moment generating function", TEST, 28, 499-521, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11749-018-0589-z")}
HJG
test.HJG(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=1.5,MC.rep=500)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.