| test.HJM | R Documentation |
Computes the test statistic of the Henze-Jimenes-Gamero-Meintanis test.
test.HJM(data, a = 1.5, MC.rep = 500, alpha = 0.05)
data |
a n x d matrix of d dimensional data vectors. |
a |
positive numeric number (tuning parameter). |
MC.rep |
number of repetitions for the Monte Carlo simulation of the critical value. |
alpha |
level of significance of the test. |
This functions evaluates the teststatistic with the given data and the specified tuning parameter a.
Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly
n \ge d+1 is needed. If that is not the case the test returns an error.
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Testname of the test.
$paramvalue tuning parameter.
$Test.valuethe value of the test statistic.
$cvthe approximated critical value.
$Decisionthe comparison of the critical value and the value of the test statistic.
Henze, N., Jimenes-Gamero, M.D., Meintanis, S.G. (2019), Characterizations of multinormality and corresponding tests of fit, including for GARCH models, Econometric Th., 35:510-546, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/S0266466618000154")}.
HJM
test.HJM(MASS::mvrnorm(10,c(0,1),diag(1,2)),a=2.5,MC=100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.