| test.MQ2 | R Documentation |
Performs the second test of multivariate normality of Manzotti and Quiroz (2001).
test.MQ2(data, MC.rep = 10000, alpha = 0.05)
data |
a n x d matrix of d dimensional data vectors. |
MC.rep |
number of repetitions for the Monte Carlo simulation of the critical value |
alpha |
level of significance of the test |
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Testname of the test.
$Test.valuethe value of the test statistic.
$cvthe approximated critical value.
$Decisionthe comparison of the critical value and the value of the test statistic.
#'
Manzotti, A., Quiroz, A.J. (2001), Spherical harmonics in quadratic forms for testing multivariate normality, Test, 10:87-104, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/BF02595825")}
MQ2
test.MQ2(MASS::mvrnorm(50,c(0,1),diag(1,2)),MC.rep=500)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.