Description Usage Arguments Details Value References See Also Examples
Computes the (approximated) Pudelko test of multivariate normality.
1 |
data |
a n x d matrix of d dimensional data vectors. |
MC.rep |
number of repetitions for the Monte Carlo simulation of the critical value. |
alpha |
level of significance of the test. |
r |
a positive number (radius of Ball) |
This functions evaluates the test statistic with the given data and the specified parameter r. Since since one has to calculate the supremum of a function inside a d-dimensional Ball of radius r. In this implementation the optim function is used.
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Testname of the test.
$paramvalue tuning parameter.
$Test.valuethe value of the test statistic.
$cvthe approximated critical value.
$Decisionthe comparison of the critical value and the value of the test statistic.
Pudelko, J. (2005), On a new affine invariant and consistent test for multivariate normality, Probab. Math. Statist., 25:43-54.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.