| test.SR | R Documentation |
Performs the test of multivariate normality of Szekely and Rizzo (2005). Note that the scaled residuals use another scaling in the estimator of the covariance matrix!
test.SR(data, MC.rep = 10000, alpha = 0.05, abb = 1e-08)
data |
a n x d matrix of d dimensional data vectors. |
MC.rep |
number of repetitions for the Monte Carlo simulation of the critical value |
alpha |
level of significance of the test |
abb |
Stop criterium. |
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Testname of the test.
$Test.valuethe value of the test statistic.
$cvthe approximated critical value.
$Decisionthe comparison of the critical value and the value of the test statistic.
#'
Szekely, G., Rizzo, M. (2005), A new test for multivariate normality, J. Multiv. Anal., 93:58-80, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jmva.2003.12.002")}
SR
test.SR(MASS::mvrnorm(50,c(0,1),diag(1,2)),MC.rep=500)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.