HV: statistic of the Henze-Visagie test

Description Usage Arguments Details Value References Examples

View source: R/teststatistics.R

Description

Computes the test statistic of the Henze-Visagie test.

Usage

1
HV(data, a = 5)

Arguments

data

a n x d numeric matrix of data values.

a

numeric number greater than 1 (tuning parameter).

Details

This functions evaluates the teststatistic with the given data and the specified tuning parameter a. Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly n ≥ d+1 is needed. If that is not the case the function returns an error.

Note that a=Inf returns the limiting test statistic with value 2*MSkew + MRSSkew.

Value

The value of the test statistic.

References

Henze, N., Visagie, J. (2019) "Testing for normality in any dimension based on a partial differential equation involving the moment generating function", to appear in Ann. Inst. Stat. Math., DOI

Examples

1
2
HV(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=5)
HV(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=Inf)

mnt documentation built on July 31, 2020, 5:07 p.m.

Related to HV in mnt...