Learn R Programming

mnt (version 1.4)

HV: statistic of the Henze-Visagie test

Description

Computes the test statistic of the Henze-Visagie test.

Usage

HV(data, a = 5)

Value

The value of the test statistic.

Arguments

data

a n x d numeric matrix of data values.

a

numeric number greater than 1 (tuning parameter).

Details

This functions evaluates the teststatistic with the given data and the specified tuning parameter a. Each row of the data Matrix contains one of the n (multivariate) sample with dimension d. To ensure that the computation works properly \(n \ge d+1\) is needed. If that is not the case the function returns an error.

Note that a=Inf returns the limiting test statistic with value 2*MSkew + MRSSkew.

References

Henze, N., Visagie, J. (2019) "Testing for normality in any dimension based on a partial differential equation involving the moment generating function", Ann. Inst. Stat. Math., 72:1109–1136, tools:::Rd_expr_doi("10.1007/s10463-019-00720-8")

Examples

Run this code
HV(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=5)
HV(MASS::mvrnorm(50,c(0,1),diag(1,2)),a=Inf)

Run the code above in your browser using DataLab