MKurt: Mardias measure of multivariate sample kurtosis
Description
This function computes the classical invariant measure of multivariate sample kurtosis due to Mardia (1970).
Usage
MKurt(data)
Value
value of sample kurtosis in the sense of Mardia.
Arguments
data
a n x d matrix of d dimensional data vectors.
Details
Multivariate sample kurtosis due to Mardia (1970) is defined by
$$b_{n,d}^{(2)}=\frac{1}{n}\sum_{j=1}^n\|Y_{n,j}\|^4,$$
where \(Y_{n,j}=S_n^{-1/2}(X_j-\overline{X}_n)\), \(\overline{X}_n\) is the sample mean and \(S_n\) is the sample covariance matrix of the random vectors \(X_1,\ldots,X_n\).To ensure that the computation works properly
\(n \ge d+1\) is needed. If that is not the case the function returns an error.
References
Mardia, K.V. (1970), Measures of multivariate skewness and kurtosis with applications, Biometrika, 57:519–530.
Henze, N. (2002), Invariant tests for multivariate normality: a critical review, Statistical Papers, 43:467–506.