This function returns the value of the first statistic of Manzotti and Quiroz (2001).
Usage
MQ1(data)
Value
Value of the test statistic
Arguments
data
a n x d matrix of d dimensional data vectors.
References
Manzotti, A., and Quiroz, A.J. (2001), Spherical harmonics in quadratic forms for testing multivariate normality, Test, 10:87–104, tools:::Rd_expr_doi("10.1007/BF02595825")