Approximates the test statistic of the Pudelko test.
Usage
PU(data, r = 2)
Value
approximate Value of the test statistic
Arguments
data
a n x d numeric matrix of data values.
r
a positive number (radius of Ball)
Details
This functions evaluates the test statistic with the given data and the specified parameter r. Since since one has to calculate the supremum of a function inside a d-dimensional Ball of radius r. In this implementation the optim function is used.
References
Pudelko, J. (2005), On a new affine invariant and consistent test for multivariate normality, Probab. Math. Statist., 25:43–54.