This function returns the value of the statistic of the test of multivariate normality (also called energy test) as in Székely and Rizzo (2005). Note that the scaled residuals use another scaling in the estimator of the covariance matrix as the other functions of the package mnt!
It is equivalent to the function mvnorm.e.
Usage
SR(data, abb = 1e-08)
Value
value of the test statistic.
Arguments
data
a n x d matrix of d dimensional data vectors.
abb
Stop criterium.
References
Székely, G., and Rizzo, M. (2005), A new test for multivariate normality, J. Multiv. Anal., 93:58–80, tools:::Rd_expr_doi("10.1016/j.jmva.2003.12.002")