View source: R/helpFunctions.R
| standard | R Documentation |
A function that computes the scaled residuals of the data.
standard(data)
data |
a n x d matrix of d dimensional data vectors.. |
A n x d matrix of the scaled residuals.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.