Description Usage Arguments Details Value References See Also Examples
Performs the test of multivariate normality of Henze and Zirkler (1990).
1 |
data |
a n x d matrix of d dimensional data vectors. |
MC.rep |
number of repetitions for the Monte Carlo simulation of the critical value |
alpha |
level of significance of the test |
A BHEP test is performed with tuning parameter β chosen in dependence of the sample size n and the dimension d, namely
β=\frac{((2d+1)n/4)^(1/(d+4))}{√{2}}.
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Testname of the test.
$paramvalue tuning parameter.
$Test.valuethe value of the test statistic.
$cvthe approximated critical value.
$Decisionthe comparison of the critical value and the value of the test statistic.
#'
Henze, N., Zirkler, B. (1990), A class of invariant consistent tests for multivariate normality, Commun.-Statist. - Th. Meth., 19:3595-3617, DOI
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.