Performs the second test of multivariate normality of Manzotti and Quiroz (2001).
Usage
test.MQ2(data, MC.rep = 10000, alpha = 0.05)
Value
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Test
name of the test.
$Test.value
the value of the test statistic.
$cv
the approximated critical value.
$Decision
the comparison of the critical value and the value of the test statistic.
#'
Arguments
data
a n x d matrix of d dimensional data vectors.
MC.rep
number of repetitions for the Monte Carlo simulation of the critical value
alpha
level of significance of the test
References
Manzotti, A., Quiroz, A.J. (2001), Spherical harmonics in quadratic forms for testing multivariate normality, Test, 10:87-104, tools:::Rd_expr_doi("10.1007/BF02595825")