Computes the (approximated) Pudelko test of multivariate normality.
Usage
test.PU(data, MC.rep = 10000, alpha = 0.05, r = 2)
Value
a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:
$Test
name of the test.
$param
value tuning parameter.
$Test.value
the value of the test statistic.
$cv
the approximated critical value.
$Decision
the comparison of the critical value and the value of the test statistic.
Arguments
data
a n x d matrix of d dimensional data vectors.
MC.rep
number of repetitions for the Monte Carlo simulation of the critical value.
alpha
level of significance of the test.
r
a positive number (radius of Ball)
Details
This functions evaluates the test statistic with the given data and the specified parameter r. Since since one has to calculate the supremum of a function inside a d-dimensional Ball of radius r. In this implementation the optim function is used.
References
Pudelko, J. (2005), On a new affine invariant and consistent test for multivariate normality, Probab. Math. Statist., 25:43-54.