test.SR: Szekely-Rizzo (energy) test

Description Usage Arguments Value References See Also Examples

View source: R/multNormTest.R

Description

Performs the test of multivariate normality of Szekely and Rizzo (2005). Note that the scaled residuals use another scaling in the estimator of the covariance matrix!

Usage

1
test.SR(data, MC.rep = 10000, alpha = 0.05, abb = 1e-08)

Arguments

data

a n x d matrix of d dimensional data vectors.

MC.rep

number of repetitions for the Monte Carlo simulation of the critical value

alpha

level of significance of the test

abb

Stop criterium.

Value

a list containing the value of the test statistic, the approximated critical value and a test decision on the significance level alpha:

$Test

name of the test.

$Test.value

the value of the test statistic.

$cv

the approximated critical value.

$Decision

the comparison of the critical value and the value of the test statistic.

#'

References

Szekely, G., Rizzo, M. (2005), A new test for multivariate normality, J. Multiv. Anal., 93:58-80, DOI

See Also

SR

Examples

1
test.SR(MASS::mvrnorm(50,c(0,1),diag(1,2)),MC.rep=500)

mnt documentation built on July 31, 2020, 5:07 p.m.

Related to test.SR in mnt...